@@ -1,5 +1,5 @@
 /*
- *  Copyright 2013-2019  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2013-2019 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -7,7 +7,6 @@
 #include "contributorrepository.h"
 #include "artikulate_debug.h"
 #include "language.h"
-#include "liblearnerprofile/src/learninggoal.h"
 #include "liblearnerprofile/src/profilemanager.h"
 #include "phoneme.h"
 #include "phonemegroup.h"
@@ -20,7 +19,6 @@
 #include <QDirIterator>
 #include <QFile>
 #include <QStandardPaths>
-#include <QUrl>
 #include <QUuid>
 
 ContributorRepository::ContributorRepository()
