@@ -1,5 +1,5 @@
 /*
- *  Copyright 2019  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2019 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -16,10 +16,8 @@
 #include <QDomDocument>
 #include <QFile>
 #include <QFileInfo>
-#include <QObject>
 #include <QQmlEngine>
 #include <QUuid>
-#include <memory>
 
 EditableCourseResource::EditableCourseResource(const QUrl &path, IResourceRepository *repository)
     : IEditableCourse()
