@@ -1,5 +1,5 @@
 /*
- *  Copyright 2013-2015  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2013-2015 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -7,8 +7,6 @@
 #include "mainwindow.h"
 #include "application.h"
 #include "artikulate_debug.h"
-#include "core/trainingsession.h"
-#include "liblearnerprofile/src/profilemanager.h"
 #include "libsound/src/outputdevicecontroller.h"
 #include "settings.h"
 #include <KAboutData>
