@@ -1,5 +1,5 @@
 /*
- *  Copyright 2013-2015  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2013-2015 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -7,10 +7,8 @@
 #include "phrasemodel.h"
 #include "artikulate_debug.h"
 #include "core/icourse.h"
-#include "core/phrase.h"
 #include "core/unit.h"
 #include <KLocalizedString>
-#include <QAbstractItemModel>
 #include <QSignalMapper>
 
 PhraseModel::PhraseModel(QObject *parent)
